@@ -33,6 +33,7 @@
 #include <KDesktopFile>
 #include <KFormat>
 #include <KLocalizedString>
+#include <KOSRelease>
 #include <KSharedConfig>
 
 #include <solid/device.h>
@@ -46,7 +47,6 @@
 #endif
 #include <sys/utsname.h>
 
-#include "OSRelease.h"
 #include "Version.h"
 
 static qlonglong calculateTotalRam()
@@ -56,7 +56,7 @@ static qlonglong calculateTotalRam()
     struct sysinfo info;
     if (sysinfo(&info) == 0)
         // manpage "sizes are given as multiples of mem_unit bytes"
-        ret = info.totalram * info.mem_unit;
+        ret = qlonglong(info.totalram) * info.mem_unit;
 #elif defined(Q_OS_FREEBSD)
     /* Stuff for sysctl */
     size_t len;
@@ -148,9 +148,9 @@ void Module::loadSoftware()
                                                           KConfig::NoGlobals);
     KConfigGroup cg = KConfigGroup(config, "General");
 
-    OSRelease os;
+    KOSRelease os;
 
-    QString logoPath = cg.readEntry("LogoPath", os.logo);
+    QString logoPath = cg.readEntry("LogoPath", os.logo());
     if (logoPath.isEmpty()) {
         logoPath = QStringLiteral("start-here-kde");
     }
@@ -160,10 +160,10 @@ void Module::loadSoftware()
     // We allow overriding of the OS name for branding purposes.
     // For example OS Ubuntu may be rebranded as Kubuntu. Also Kubuntu Active
     // as a product brand is different from Kubuntu.
-    const QString distroName = cg.readEntry("Name", os.name);
+    const QString distroName = cg.readEntry("Name", os.name());
     const QString osrVersion = cg.readEntry("UseOSReleaseVersion", false)
-            ? os.version
-            : os.versionId;
+            ? os.version()
+            : os.versionId();
     const QString versionId = cg.readEntry("Version", osrVersion);
     const QString distroNameVersion = QStringLiteral("%1 %2").arg(distroName, versionId);
     ui->nameVersionLabel->setText(distroNameVersion);
@@ -173,14 +173,14 @@ void Module::loadSoftware()
     labelsForClipboard << qMakePair(dummyDistroDescriptionLabel, ui->nameVersionLabel);
     englishTextForClipboard += QStringLiteral("Operating System: %1\n").arg(distroNameVersion);
 
-    const QString variant = cg.readEntry("Variant", os.variant);
+    const QString variant = cg.readEntry("Variant", os.variant());
     if (variant.isEmpty()) {
         ui->variantLabel->hide();
     } else {
         ui->variantLabel->setText(variant);
     }
 
-    const QString url = cg.readEntry("Website", os.homeUrl);
+    const QString url = cg.readEntry("Website", os.homeUrl());
     if (url.isEmpty()) {
         ui->urlLabel->hide();
     } else {
